==> 9.0.2.tar.gz: leenooks/resources/themes/adminlte/views/layouts/partials/htmlheader.blade.php <==
<head>
	<meta charset="UTF-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<title>{{ config('app.name') }} - @yield('htmlheader_title','Your title here')</title>
	<meta content='width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no' name='viewport'>
	<!-- CSRF Token -->
	<meta name="csrf-token" content="{{ csrf_token() }}">

	<link rel="stylesheet" href="{{ asset('//cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/css/bootstrap.min.css') }}" integrity="sha384-B0vP5xmATw1+K9KRQjQERJvTumQW0nPEzvF6L/Z6nronJ3oUOFUFpCjEUQouq2+l" crossorigin="anonymous">

	<!-- Font Awesome Icons -->
	<link rel="stylesheet" href="{{ asset('//use.fontawesome.com/releases/v5.15.3/css/all.css') }}">
	{{--
	<link rel="stylesheet" href="{{ asset('//use.fontawesome.com/releases/v5.15.3/css/v4-shims.css') }}">
	--}}

	<!-- Theme style -->
	<link rel="stylesheet" href="{{ asset('//cdn.jsdelivr.net/npm/admin-lte@3.1.0/dist/css/adminlte.min.css') }}">

	<!-- Google Font: Source Sans Pro -->
	<link href="https://fonts.googleapis.com/css2?family={{ str_replace(' ','+',config('app.font') ?: 'IBM Plex Sans') }}:wght@300&display=swap" rel="stylesheet">

	@if(file_exists('css/social.css'))
		<!-- Social Logins -->
		<link rel="stylesheet" href="{{ asset('/css/social.css') }}">
	@endif
	@if(file_exists('css/print.css'))
		<!-- Printing Modifications -->
		<link rel="stylesheet" href="{{ asset('/css/print.css') }}">
	@endif

	{{--
	<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
	<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
	<!--[if lt IE 9]>
		<script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
		<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
	<![endif]-->
	--}}

	<!-- STYLESHEETS -->
	{!! Asset::styles() !!}

	@if(file_exists('css/fixes.css'))
		<!-- CSS Fixes -->
		<link rel="stylesheet" href="{{ asset('/css/fixes.css') }}">
	@endif

	@if(file_exists('css/custom.css'))
		<!-- Custom CSS -->
		<link rel="stylesheet" href="{{ asset('/css/custom.css') }}">
	@endif
</head>

==> 9.2.4.tar.gz: leenooks/resources/themes/adminlte/views/layouts/partials/htmlheader.blade.php <==
<head>
	<meta charset="UTF-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<title>{{ config('app.name') }} - @yield('htmlheader_title','Your title here')</title>
	<meta content='width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no' name='viewport'>
	<!-- CSRF Token -->
	<meta name="csrf-token" content="{{ csrf_token() }}">

	{{--
	<!-- Included in adminlte -->
	<link rel="stylesheet" href="//cdn.jsdelivr.net/npm/bootstrap@4.6.1/dist/css/bootstrap.min.css" integrity="sha384-B0vP5xmATw1+K9KRQjQERJvTumQW0nPEzvF6L/Z6nronJ3oUOFUFpCjEUQouq2+l" crossorigin="anonymous">
	--}}

	<!-- Font Awesome Icons -->
	<link rel="stylesheet" href="//use.fontawesome.com/releases/v5.15.4/css/all.css">
	{{--
	<link rel="stylesheet" href="//use.fontawesome.com/releases/v5.15.4/css/v4-shims.css">
	--}}

	<!-- Theme style -->
	<link rel="stylesheet" href="//cdn.jsdelivr.net/npm/admin-lte@3.2.0/dist/css/adminlte.min.css">

	<!-- Google Font: Source Sans Pro -->
	<link href="https://fonts.googleapis.com/css2?family={{ str_replace(' ','+',config('app.font') ?: 'IBM Plex Sans') }}:wght@300&display=swap" rel="stylesheet">

	@if(file_exists('css/social.css'))
		<!-- Social Logins -->
		<link rel="stylesheet" href="{{ asset('css/social.css') }}">
	@endif
	@if(file_exists('css/print.css'))
		<!-- Printing Modifications -->
		<link rel="stylesheet" href="{{ asset('css/print.css') }}">
	@endif

	{{--
	<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
	<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
	<!--[if lt IE 9]>
		<script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
		<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
	<![endif]-->
	--}}

	<!-- STYLESHEETS -->
	{!! Asset::styles() !!}

	@yield('page-styles')

	@if(file_exists('css/fixes.css'))
		<!-- CSS Fixes -->
		<link rel="stylesheet" href="{{ asset('css/fixes.css') }}">
	@endif

	@if(file_exists('css/custom.css'))
		<!-- Custom CSS -->
		<link rel="stylesheet" href="{{ asset('css/custom.css') }}">
	@endif
</head>
